==> func_adl_servicex_xaodr22-1.1.4.22.2.113-py3-none-any.whl: func_adl_servicex_xaodr22/elementlink_datavector_xaod_afpsihitscluster_v1__.py <==
from __future__ import annotations
import ast
from typing import Tuple, TypeVar, Iterable
from func_adl import ObjectStream, func_adl_callback, func_adl_parameterized_call
import func_adl_servicex_xaodr22

_method_map = {
    'isValid': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'isValid',
        'return_type': 'bool',
    },
    'stationID': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'stationID',
        'return_type': 'int',
        'deref_count': 2
    },
    'pixelLayerID': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'pixelLayerID',
        'return_type': 'int',
        'deref_count': 2
    },
    'xLocal': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'xLocal',
        'return_type': 'float',
        'deref_count': 2
    },
    'xLocalErr': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'xLocalErr',
        'return_type': 'float',
        'deref_count': 2
    },
    'yLocal': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'yLocal',
        'return_type': 'float',
        'deref_count': 2
    },
    'yLocalErr': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'yLocalErr',
        'return_type': 'float',
        'deref_count': 2
    },
    'zLocal': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'zLocal',
        'return_type': 'float',
        'deref_count': 2
    },
    'zLocalErr': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'zLocalErr',
        'return_type': 'float',
        'deref_count': 2
    },
    'depositedCharge': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'depositedCharge',
        'return_type': 'float',
        'deref_count': 2
    },
    'nHits': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'nHits',
        'return_type': 'int',
        'deref_count': 2
    },
    'hitsLinks': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'hitsLinks',
        'return_type_element': 'ElementLink<DataVector<xAOD::AFPSiHit_v2>>',
        'return_type_collection': 'const vector<ElementLink<DataVector<xAOD::AFPSiHit_v2>>>',
        'deref_count': 2
    },
    'clusterAlgID': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'clusterAlgID',
        'return_type': 'int',
        'deref_count': 2
    },
    'index': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'index',
        'return_type': 'int',
        'deref_count': 2
    },
    'usingPrivateStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'usingPrivateStore',
        'return_type': 'bool',
        'deref_count': 2
    },
    'usingStandaloneStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'usingStandaloneStore',
        'return_type': 'bool',
        'deref_count': 2
    },
    'hasStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'hasStore',
        'return_type': 'bool',
        'deref_count': 2
    },
    'hasNonConstStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'hasNonConstStore',
        'return_type': 'bool',
        'deref_count': 2
    },
    'clearDecorations': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'clearDecorations',
        'return_type': 'bool',
        'deref_count': 2
    },
    'trackIndices': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'trackIndices',
        'return_type': 'bool',
        'deref_count': 2
    },
    'auxdataConst': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'auxdataConst',
        'return_type': 'U',
        'deref_count': 2
    },
    'isAvailable': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'isAvailable',
        'return_type': 'bool',
        'deref_count': 2
    },
}


T = TypeVar('T')


def _add_method_metadata(s: ObjectStream[T], a: ast.Call) -> Tuple[ObjectStream[T], ast.Call]:
    '''Add metadata for a collection to the func_adl stream if we know about it
    '''
    assert isinstance(a.func, ast.Attribute)
    if a.func.attr in _method_map:
        s_update = s.MetaData(_method_map[a.func.attr])
        return s_update, a
    else:
        return s, a


@func_adl_callback(_add_method_metadata)
class ElementLink_DataVector_xAOD_AFPSiHitsCluster_v1__:
    "A class"

    def isValid(self) -> bool:
        "A method"
        ...

    def stationID(self) -> int:
        "A method"
        ...

    def pixelLayerID(self) -> int:
        "A method"
        ...

    def xLocal(self) -> float:
        "A method"
        ...

    def xLocalErr(self) -> float:
        "A method"
        ...

    def yLocal(self) -> float:
        "A method"
        ...

    def yLocalErr(self) -> float:
        "A method"
        ...

    def zLocal(self) -> float:
        "A method"
        ...

    def zLocalErr(self) -> float:
        "A method"
        ...

    def depositedCharge(self) -> float:
        "A method"
        ...

    def nHits(self) -> int:
        "A method"
        ...

    def hitsLinks(self) -> func_adl_servicex_xaodr22.vector_elementlink_datavector_xaod_afpsihit_v2___.vector_ElementLink_DataVector_xAOD_AFPSiHit_v2___:
        "A method"
        ...

    def clusterAlgID(self) -> int:
        "A method"
        ...

    def index(self) -> int:
        "A method"
        ...

    def usingPrivateStore(self) -> bool:
        "A method"
        ...

    def usingStandaloneStore(self) -> bool:
        "A method"
        ...

    def hasStore(self) -> bool:
        "A method"
        ...

    def hasNonConstStore(self) -> bool:
        "A method"
        ...

    def clearDecorations(self) -> bool:
        "A method"
        ...

    def trackIndices(self) -> bool:
        "A method"
        ...

    @func_adl_parameterized_call(lambda s, a, param_1: func_adl_servicex_xaodr22.type_support.cpp_generic_1arg_callback('auxdataConst', s, a, param_1))
    @property
    def auxdataConst(self) -> func_adl_servicex_xaodr22.type_support.index_type_forwarder[str]:
        "A method"
        ...

    @func_adl_parameterized_call(lambda s, a, param_1: func_adl_servicex_xaodr22.type_support.cpp_generic_1arg_callback('isAvailable', s, a, param_1))
    @property
    def isAvailable(self) -> func_adl_servicex_xaodr22.type_support.index_type_forwarder[str]:
        "A method"
        ...

==> func_adl_servicex_xaodr22-2.0.1.22.2.107-py3-none-any.whl: func_adl_servicex_xaodr22/elementlink_datavector_xaod_afpsihitscluster_v1__.py <==
from __future__ import annotations
import ast
from typing import Tuple, TypeVar, Iterable
from func_adl import ObjectStream, func_adl_callback, func_adl_parameterized_call
from enum import Enum
import func_adl_servicex_xaodr22

_method_map = {
    'isValid': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'isValid',
        'return_type': 'bool',
    },
    'stationID': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'stationID',
        'return_type': 'int',
        'deref_count': 2
    },
    'pixelLayerID': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'pixelLayerID',
        'return_type': 'int',
        'deref_count': 2
    },
    'xLocal': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'xLocal',
        'return_type': 'float',
        'deref_count': 2
    },
    'xLocalErr': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'xLocalErr',
        'return_type': 'float',
        'deref_count': 2
    },
    'yLocal': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'yLocal',
        'return_type': 'float',
        'deref_count': 2
    },
    'yLocalErr': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'yLocalErr',
        'return_type': 'float',
        'deref_count': 2
    },
    'zLocal': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'zLocal',
        'return_type': 'float',
        'deref_count': 2
    },
    'zLocalErr': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'zLocalErr',
        'return_type': 'float',
        'deref_count': 2
    },
    'depositedCharge': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'depositedCharge',
        'return_type': 'float',
        'deref_count': 2
    },
    'nHits': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'nHits',
        'return_type': 'int',
        'deref_count': 2
    },
    'hitsLinks': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'hitsLinks',
        'return_type_element': 'ElementLink<DataVector<xAOD::AFPSiHit_v2>>',
        'return_type_collection': 'const vector<ElementLink<DataVector<xAOD::AFPSiHit_v2>>>',
        'deref_count': 2
    },
    'clusterAlgID': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'clusterAlgID',
        'return_type': 'int',
        'deref_count': 2
    },
    'index': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'index',
        'return_type': 'int',
        'deref_count': 2
    },
    'usingPrivateStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'usingPrivateStore',
        'return_type': 'bool',
        'deref_count': 2
    },
    'usingStandaloneStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'usingStandaloneStore',
        'return_type': 'bool',
        'deref_count': 2
    },
    'hasStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'hasStore',
        'return_type': 'bool',
        'deref_count': 2
    },
    'hasNonConstStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'hasNonConstStore',
        'return_type': 'bool',
        'deref_count': 2
    },
    'clearDecorations': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'clearDecorations',
        'return_type': 'bool',
        'deref_count': 2
    },
    'trackIndices': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'trackIndices',
        'return_type': 'bool',
        'deref_count': 2
    },
    'auxdataConst': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'auxdataConst',
        'return_type': 'U',
        'deref_count': 2
    },
    'isAvailable': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ElementLink<DataVector<xAOD::AFPSiHitsCluster_v1>>',
        'method_name': 'isAvailable',
        'return_type': 'bool',
        'deref_count': 2
    },
}

_enum_map = {      
}

T = TypeVar('T')


def _add_method_metadata(s: ObjectStream[T], a: ast.Call) -> Tuple[ObjectStream[T], ast.Call]:
    '''Add metadata for a collection to the func_adl stream if we know about it
    '''
    assert isinstance(a.func, ast.Attribute)
    if a.func.attr in _method_map:
        s_update = s.MetaData(_method_map[a.func.attr])
        for md in _enum_map.get(a.func.attr, []):
            s_update = s_update.MetaData(md)
        return s_update, a
    else:
        return s, a


@func_adl_callback(_add_method_metadata)
class ElementLink_DataVector_xAOD_AFPSiHitsCluster_v1__:
    "A class"


    def isValid(self) -> bool:
        "A method"
        ...

    def stationID(self) -> int:
        "A method"
        ...

    def pixelLayerID(self) -> int:
        "A method"
        ...

    def xLocal(self) -> float:
        "A method"
        ...

    def xLocalErr(self) -> float:
        "A method"
        ...

    def yLocal(self) -> float:
        "A method"
        ...

    def yLocalErr(self) -> float:
        "A method"
        ...

    def zLocal(self) -> float:
        "A method"
        ...

    def zLocalErr(self) -> float:
        "A method"
        ...

    def depositedCharge(self) -> float:
        "A method"
        ...

    def nHits(self) -> int:
        "A method"
        ...

    def hitsLinks(self) -> func_adl_servicex_xaodr22.vector_elementlink_datavector_xaod_afpsihit_v2___.vector_ElementLink_DataVector_xAOD_AFPSiHit_v2___:
        "A method"
        ...

    def clusterAlgID(self) -> int:
        "A method"
        ...

    def index(self) -> int:
        "A method"
        ...

    def usingPrivateStore(self) -> bool:
        "A method"
        ...

    def usingStandaloneStore(self) -> bool:
        "A method"
        ...

    def hasStore(self) -> bool:
        "A method"
        ...

    def hasNonConstStore(self) -> bool:
        "A method"
        ...

    def clearDecorations(self) -> bool:
        "A method"
        ...

    def trackIndices(self) -> bool:
        "A method"
        ...

    @func_adl_parameterized_call(lambda s, a, param_1: func_adl_servicex_xaodr22.type_support.cpp_generic_1arg_callback('auxdataConst', s, a, param_1))
    @property
    def auxdataConst(self) -> func_adl_servicex_xaodr22.type_support.index_type_forwarder[func_adl_servicex_xaodr22.str.str]:
        "A method"
        ...

    @func_adl_parameterized_call(lambda s, a, param_1: func_adl_servicex_xaodr22.type_support.cpp_generic_1arg_callback('isAvailable', s, a, param_1))
    @property
    def isAvailable(self) -> func_adl_servicex_xaodr22.type_support.index_type_forwarder[func_adl_servicex_xaodr22.str.str]:
        "A method"
        ...
